library action_consolidator;

import 'dart:async';

class ActionConsolidator<V> {

  Map<String, Future<V>> _running;

  /**
   * Typical constructor
   */
  ActionConsolidator() {
    this._running  = new Map<String, Future<V>>();
  }

  /**
   * The asynchronous action consolidator and deduplicator
   *
   * @param {String} key       - The key to consolidate on
   * @param {Future<V>} action - The async action to consolidate
   * @return {Future<V>}       - The completion future
   */
  Future<V> run(String key, Future<V> action()) {
    if (!this._running.containsKey(key)) {
      Future<V> future = action();
      this._running[key] = future;
    }
    return this._running[key];
  }

}